@@ -24,6 +24,7 @@ from livestyled.models.location import Location
 from livestyled.models.magic_field import MagicField
 from livestyled.models.news import News
 from livestyled.models.order import Order, OrderItem
+from livestyled.models.payment import MerchantAccount, PaymentCustomer, PaymentGateway, PaymentIntent, PaymentSource
 from livestyled.models.product import (
     Product,
     ProductCategory,
@@ -70,9 +71,14 @@ __all__ = [
     LeagueTableGroup,
     Location,
     MagicField,
+    MerchantAccount,
     News,
     Order,
     OrderItem,
+    PaymentCustomer,
+    PaymentGateway,
+    PaymentIntent,
+    PaymentSource,
     Product,
     ProductCategory,
     ProductImage,
