@@ -157,3 +157,11 @@ class Order:
             external_id=None,
             seat_info=None
         )
+
+    def diff(self, other):
+        differences = {}
+        fields = ('external_id', 'status', 'collection_preference_type', 'check_in_time')
+        for field in fields:
+            if getattr(self, field) != getattr(other, field):
+                differences[field] = getattr(self, field)
+        return differences
