@@ -26,6 +26,7 @@ from livestyled.models import (
     MagicField,
     News,
     Order,
+    PaymentIntent,
     Product,
     ProductCategory,
     ProductModifierItem,
@@ -67,8 +68,13 @@ from livestyled.schemas import (
     LeagueTableSchema,
     LocationSchema,
     MagicFieldSchema,
+    MerchantAccountSchema,
     NewsSchema,
     OrderSchema,
+    PaymentCustomerSchema,
+    PaymentGatewaySchema,
+    PaymentIntentSchema,
+    PaymentSourceSchema,
     ProductCategorySchema,
     ProductModifierItemSchema,
     ProductModifierListSchema,
@@ -868,11 +874,17 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
     def get_orders(
             self,
             external_id: str or None = None,
+            filters: Dict or None = None
     ) -> Generator[Order, None, None]:
+        filter_param = {}
+
+        if filters:
+            filter_param = filters
+
         if external_id:
-            return self._get_resource_list(OrderSchema, external_id)
-        else:
-            return self._get_resource_list(OrderSchema)
+            filter_param['externalId'] = external_id
+
+        return self._get_resource_list(OrderSchema, filters=filter_param)
 
     def update_order(
             self,
@@ -894,7 +906,7 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
             external_id: str or None = None
     ) -> Generator[Product, None, None]:
         if external_id:
-            return self._get_resource_list(ProductSchema, external_id=external_id)
+            return self._get_resource_list(ProductSchema, external_id=external_id, order_by={'externalId': 'ASC'})
         else:
             return self._get_resource_list(ProductSchema)
 
@@ -1347,6 +1359,53 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
             return self._get_resource_list(DeviceFormDataSchema, filters=filters)
         return self._get_resource_list(DeviceFormDataSchema)
 
+    def get_merchant_account(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, MerchantAccountSchema)
+
+    def get_merchant_accounts(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(MerchantAccountSchema, filters=filters)
+
+    def create_merchant_account(self, attributes: Dict) -> Dict:
+        payload = MerchantAccountSchema().dump(attributes)
+        merchant_account = self._api_post(
+            'v4/{}'.format(MerchantAccountSchema.Meta.url),
+            payload
+        )
+        return MerchantAccountSchema().load(merchant_account)
+
+    def get_payment_gateway(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(
+            id,
+            PaymentGatewaySchema,
+        )
+
+    def get_payment_gateways(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(PaymentGatewaySchema, filters=filters)
+
+    def get_payment_source(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, PaymentSourceSchema)
+
+    def get_payment_sources(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(PaymentSourceSchema, filters=filters)
+
+    def get_payment_intent(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, PaymentIntentSchema)
+
+    def get_payment_intents(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(PaymentIntentSchema, filters=filters)
+
+    def update_payment_intent(self, payment_intent: PaymentIntent, attributes: Dict) -> PaymentIntent:
+        return self._update_resource(PaymentIntentSchema, payment_intent.id, attributes)
+
+    def get_payment_customer(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(
+            id,
+            PaymentCustomerSchema,
+        )
+
+    def get_payment_customers(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(PaymentCustomerSchema, filters=filters)
+
     # ---- CURRENCIES
 
     def get_currencies(
